@@ -32,6 +32,9 @@ AUTHFAILURE_SIGN = 'AuthFailure.Sign'
 # 验证失败。
 AUTHFAILURE_VERIFYERROR = 'AuthFailure.VerifyError'
 
+# Token校验失败。
+AUTHFAILURE_VERIFYTOKENFAILURE = 'AuthFailure.VerifyTokenFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -200,6 +203,9 @@ FAILEDOPERATION_MERCHANTEXIST = 'FailedOperation.MerchantExist'
 # 查无此商户。
 FAILEDOPERATION_MERCHANTNOTEXIST = 'FailedOperation.MerchantNotExist'
 
+# 商户不存在。
+FAILEDOPERATION_MERCHANTNOTEXISTS = 'FailedOperation.MerchantNotExists'
+
 # 商户权限错误。
 FAILEDOPERATION_MERCHANTPERMISSIONERROR = 'FailedOperation.MerchantPermissionError'
 
@@ -293,6 +299,12 @@ FAILEDOPERATION_QUERYRESULTNULL = 'FailedOperation.QueryResultNull'
 # 超出商户单日转账额度。
 FAILEDOPERATION_QUOTAEXCEED = 'FailedOperation.QuotaExceed'
 
+# 退款信息重复。
+FAILEDOPERATION_REFUNDINFODUPLICATE = 'FailedOperation.RefundInfoDuplicate'
+
+# 不可重试退款。
+FAILEDOPERATION_REFUNDNOTRETRIEABLE = 'FailedOperation.RefundNotRetrieable'
+
 # 退款处理中。
 FAILEDOPERATION_REFUNDPROCESSING = 'FailedOperation.RefundProcessIng'
 
